==> cdk8s-plus-20-1.0.0-beta.6-sources.jar: org/cdk8s/plus20/ServiceAccountProps.java <==
package org.cdk8s.plus20;

/**
 * Properties for initialization of `ServiceAccount`.
 * <p>
 * Properties for initialization of <code>ServiceAccount</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-24T02:12:24.269Z")
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.ServiceAccountProps")
@software.amazon.jsii.Jsii.Proxy(ServiceAccountProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ServiceAccountProps extends software.amazon.jsii.JsiiSerializable, org.cdk8s.plus20.ResourceProps {

    /**
     * List of secrets allowed to be used by pods running using this ServiceAccount.
     * <p>
     * @see https://kubernetes.io/docs/concepts/configuration/secret
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<org.cdk8s.plus20.ISecret> getSecrets() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ServiceAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ServiceAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ServiceAccountProps> {
        private java.util.List<org.cdk8s.plus20.ISecret> secrets;
        private org.cdk8s.ApiObjectMetadata metadata;

        /**
         * Sets the value of {@link ServiceAccountProps#getSecrets}
         * @param secrets List of secrets allowed to be used by pods running using this ServiceAccount.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder secrets(java.util.List<? extends org.cdk8s.plus20.ISecret> secrets) {
            this.secrets = (java.util.List<org.cdk8s.plus20.ISecret>)secrets;
            return this;
        }

        /**
         * Sets the value of {@link ServiceAccountProps#getMetadata}
         * @param metadata Metadata that all persisted resources must have, which includes all objects users must create.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metadata(org.cdk8s.ApiObjectMetadata metadata) {
            this.metadata = metadata;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServiceAccountProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ServiceAccountProps build() {
            return new Jsii$Proxy(secrets, metadata);
        }
    }

    /**
     * An implementation for {@link ServiceAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ServiceAccountProps {
        private final java.util.List<org.cdk8s.plus20.ISecret> secrets;
        private final org.cdk8s.ApiObjectMetadata metadata;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.secrets = software.amazon.jsii.Kernel.get(this, "secrets", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.ISecret.class)));
            this.metadata = software.amazon.jsii.Kernel.get(this, "metadata", software.amazon.jsii.NativeType.forClass(org.cdk8s.ApiObjectMetadata.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.util.List<? extends org.cdk8s.plus20.ISecret> secrets, final org.cdk8s.ApiObjectMetadata metadata) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.secrets = (java.util.List<org.cdk8s.plus20.ISecret>)secrets;
            this.metadata = metadata;
        }

        @Override
        public final java.util.List<org.cdk8s.plus20.ISecret> getSecrets() {
            return this.secrets;
        }

        @Override
        public final org.cdk8s.ApiObjectMetadata getMetadata() {
            return this.metadata;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSecrets() != null) {
                data.set("secrets", om.valueToTree(this.getSecrets()));
            }
            if (this.getMetadata() != null) {
                data.set("metadata", om.valueToTree(this.getMetadata()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("cdk8s-plus-20.ServiceAccountProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ServiceAccountProps.Jsii$Proxy that = (ServiceAccountProps.Jsii$Proxy) o;

            if (this.secrets != null ? !this.secrets.equals(that.secrets) : that.secrets != null) return false;
            return this.metadata != null ? this.metadata.equals(that.metadata) : that.metadata == null;
        }

        @Override
        public final int hashCode() {
            int result = this.secrets != null ? this.secrets.hashCode() : 0;
            result = 31 * result + (this.metadata != null ? this.metadata.hashCode() : 0);
            return result;
        }
    }
}

==> cdk8s-plus-20-2.0.0-beta.6-sources.jar: org/cdk8s/plus20/ServiceAccountProps.java <==
package org.cdk8s.plus20;

/**
 * Properties for initialization of `ServiceAccount`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.59.0 (build eb02c92)", date = "2022-05-19T02:54:09.029Z")
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.ServiceAccountProps")
@software.amazon.jsii.Jsii.Proxy(ServiceAccountProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ServiceAccountProps extends software.amazon.jsii.JsiiSerializable, org.cdk8s.plus20.ResourceProps {

    /**
     * Indicates whether pods running as this service account should have an API token automatically mounted.
     * <p>
     * Can be overridden at the pod level.
     * <p>
     * Default: true
     * <p>
     * @see https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/#use-the-default-service-account-to-access-the-api-server
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAutomountToken() {
        return null;
    }

    /**
     * List of secrets allowed to be used by pods running using this ServiceAccount.
     * <p>
     * @see https://kubernetes.io/docs/concepts/configuration/secret
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<org.cdk8s.plus20.ISecret> getSecrets() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ServiceAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ServiceAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ServiceAccountProps> {
        java.lang.Boolean automountToken;
        java.util.List<org.cdk8s.plus20.ISecret> secrets;
        org.cdk8s.ApiObjectMetadata metadata;

        /**
         * Sets the value of {@link ServiceAccountProps#getAutomountToken}
         * @param automountToken Indicates whether pods running as this service account should have an API token automatically mounted.
         *                       Can be overridden at the pod level.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder automountToken(java.lang.Boolean automountToken) {
            this.automountToken = automountToken;
            return this;
        }

        /**
         * Sets the value of {@link ServiceAccountProps#getSecrets}
         * @param secrets List of secrets allowed to be used by pods running using this ServiceAccount.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder secrets(java.util.List<? extends org.cdk8s.plus20.ISecret> secrets) {
            this.secrets = (java.util.List<org.cdk8s.plus20.ISecret>)secrets;
            return this;
        }

        /**
         * Sets the value of {@link ServiceAccountProps#getMetadata}
         * @param metadata Metadata that all persisted resources must have, which includes all objects users must create.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metadata(org.cdk8s.ApiObjectMetadata metadata) {
            this.metadata = metadata;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServiceAccountProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ServiceAccountProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ServiceAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ServiceAccountProps {
        private final java.lang.Boolean automountToken;
        private final java.util.List<org.cdk8s.plus20.ISecret> secrets;
        private final org.cdk8s.ApiObjectMetadata metadata;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.automountToken = software.amazon.jsii.Kernel.get(this, "automountToken", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.secrets = software.amazon.jsii.Kernel.get(this, "secrets", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.ISecret.class)));
            this.metadata = software.amazon.jsii.Kernel.get(this, "metadata", software.amazon.jsii.NativeType.forClass(org.cdk8s.ApiObjectMetadata.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.automountToken = builder.automountToken;
            this.secrets = (java.util.List<org.cdk8s.plus20.ISecret>)builder.secrets;
            this.metadata = builder.metadata;
        }

        @Override
        public final java.lang.Boolean getAutomountToken() {
            return this.automountToken;
        }

        @Override
        public final java.util.List<org.cdk8s.plus20.ISecret> getSecrets() {
            return this.secrets;
        }

        @Override
        public final org.cdk8s.ApiObjectMetadata getMetadata() {
            return this.metadata;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAutomountToken() != null) {
                data.set("automountToken", om.valueToTree(this.getAutomountToken()));
            }
            if (this.getSecrets() != null) {
                data.set("secrets", om.valueToTree(this.getSecrets()));
            }
            if (this.getMetadata() != null) {
                data.set("metadata", om.valueToTree(this.getMetadata()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("cdk8s-plus-20.ServiceAccountProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ServiceAccountProps.Jsii$Proxy that = (ServiceAccountProps.Jsii$Proxy) o;

            if (this.automountToken != null ? !this.automountToken.equals(that.automountToken) : that.automountToken != null) return false;
            if (this.secrets != null ? !this.secrets.equals(that.secrets) : that.secrets != null) return false;
            return this.metadata != null ? this.metadata.equals(that.metadata) : that.metadata == null;
        }

        @Override
        public final int hashCode() {
            int result = this.automountToken != null ? this.automountToken.hashCode() : 0;
            result = 31 * result + (this.secrets != null ? this.secrets.hashCode() : 0);
            result = 31 * result + (this.metadata != null ? this.metadata.hashCode() : 0);
            return result;
        }
    }
}
